package com.jh.boot.attachment.api;

import java.io.InputStream;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.ResponseBody;

import com.jh.boot.attachment.Attachment;
import com.jh.boot.attachment.AttachmentService;
import com.jh.boot.web.error.NotFoundException;

@Controller
@ConditionalOnBean(AttachmentService.class)
public class AttachmentApiController {
	
	@Autowired
	private AttachmentService service;

	
	@GetMapping("/attachments/{unitId}/{objectType}/{objectId}")
	public @ResponseBody List<Attachment> listAttachments(@PathVariable("unitId") Long unitId, @PathVariable("objectType") String objectType, @PathVariable("objectId") Long objectId) {
		return service.fetchAttachments(unitId, objectType, objectId);
	}
	
	
	@GetMapping("/attachments/{attachmentId}")
    public ResponseEntity<InputStreamResource> fetch(@PathVariable("unitId") Long unitId, @PathVariable("objectType") String objectType, @PathVariable("objectId") Long objectId, @PathVariable("attachmentId") Long attachmentId) {
    	Attachment a = service.fetchAttachment(attachmentId);
    	if (a == null) {
    		throw new NotFoundException();
    	}
    	
    	InputStream is = service.fetchAttachmentBody(a);
    	if (is == null) {
    		throw new NotFoundException();
    	}
    	
    	HttpHeaders headers = new HttpHeaders();
    	headers.setContentType(MediaType.APPLICATION_OCTET_STREAM);
    	headers.set("Content-Disposition", "attachment; filename=\"" + a.getName() + "\"");
    	
    	return new ResponseEntity<>(content, headers, HttpStatus.OK);
    }
	
}
